@@ -4,15 +4,16 @@ from conan.internal.api.install.generators import write_generators
 from conan.internal.conan_app import ConanBasicApp
 from conan.internal.deploy import do_deploys
 
-from conans.client.graph.install_graph import InstallGraph
-from conans.client.installer import BinaryInstaller
+from conan.internal.graph.install_graph import InstallGraph
+from conan.internal.graph.installer import BinaryInstaller
 from conan.errors import ConanInvalidConfiguration
 
 
 class InstallAPI:
 
-    def __init__(self, conan_api):
+    def __init__(self, conan_api, helpers):
         self.conan_api = conan_api
+        self._helpers = helpers
 
     def install_binaries(self, deps_graph, remotes=None):
         """ Install binaries for dependency graph
@@ -21,7 +22,7 @@ class InstallAPI:
         """
         app = ConanBasicApp(self.conan_api)
         installer = BinaryInstaller(app, self.conan_api.config.global_conf, app.editable_packages,
-                                    self.conan_api.config.hook_manager)
+                                    self._helpers.hook_manager)
         install_graph = InstallGraph(deps_graph)
         install_graph.raise_errors()
         install_order = install_graph.install_order()
@@ -35,7 +36,7 @@ class InstallAPI:
         """
         app = ConanBasicApp(self.conan_api)
         installer = BinaryInstaller(app, self.conan_api.config.global_conf, app.editable_packages,
-                                    self.conan_api.config.hook_manager)
+                                    self._helpers.hook_manager)
         installer.install_system_requires(graph, only_info)
 
     def install_sources(self, graph, remotes):
@@ -46,7 +47,7 @@ class InstallAPI:
         """
         app = ConanBasicApp(self.conan_api)
         installer = BinaryInstaller(app, self.conan_api.config.global_conf, app.editable_packages,
-                                    self.conan_api.config.hook_manager)
+                                    self._helpers.hook_manager)
         installer.install_sources(graph, remotes)
 
     # TODO: Look for a better name
@@ -87,7 +88,7 @@ class InstallAPI:
             if gen not in final_generators:
                 final_generators.append(gen)
         conanfile.generators = final_generators
-        hook_manager = self.conan_api.config.hook_manager
+        hook_manager = self._helpers.hook_manager
         write_generators(conanfile, hook_manager, self.conan_api.home_folder,
                          envs_generation=envs_generation)
 
